@@ -8,7 +8,7 @@ use Test::More;
 plan skip_all => 'no nvim listening' unless $ENV{NVIM_LISTEN_ADDRESS};
 
 use Neovim::RPC;
-use Future;
+use Promises qw/ deferred /;
 
 use experimental 'signatures';
 
@@ -22,7 +22,7 @@ $rpc->api->vim_eval( str => "rpcnotify( nvimx_channel, 'load_plugin', 'FileToPac
 
 $rpc->api->vim_eval( str => "rpcrequest( nvimx_channel, 'file_to_package_name' )" );
 
-my $end_loop = Future->new;
+my $end_loop = deferred;
 
 $rpc->loop($end_loop);
 
