@@ -3,9 +3,6 @@
 use strict;
 use warnings;
 
-use lib '/home/yanick/work/neovim/lib';
-use lib '/home/yanick/work/MessagePack/lib';
-
 use  Neovim::RPC;
 
 my $rpc = Neovim::RPC->new;
