@@ -1,13 +1,13 @@
 package Neovim::RPC::API::AutoDiscover;
 our $AUTHORITY = 'cpan:YANICK';
-$Neovim::RPC::API::AutoDiscover::VERSION = '0.1.0';
+$Neovim::RPC::API::AutoDiscover::VERSION = '0.2.0';
 use strict;
 use warnings;
 
 use Moose;
 with 'Neovim::RPC::API';
 
-use Future;
+use Promises qw/ deferred /;
 
 use experimental 'postderef';
 
@@ -16,9 +16,9 @@ sub BUILD {
     
     $self->add_command({ name => 'vim_get_api_info' });
 
-    my $done = Future->new;
+    my $promise = deferred;
 
-    $self->vim_get_api_info->on_done(sub {
+    $self->vim_get_api_info->done(sub {
         my( $response ) = @_;
 
         $self->channel_id( $response->[0] );
@@ -37,10 +37,10 @@ sub BUILD {
 
         $self->vim_set_var( name => 'nvimx_channel', value => $self->channel_id );
 
-        $done->done;
+        $promise->resolve;
     } );
 
-    $self->rpc->loop( $done );
+    $self->rpc->loop( $promise );
 }
 
 1;
@@ -57,7 +57,7 @@ Neovim::RPC::API::AutoDiscover
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 AUTHOR
 
