@@ -1,6 +1,6 @@
 package Neovim::RPC::API::Command;
 our $AUTHORITY = 'cpan:YANICK';
-$Neovim::RPC::API::Command::VERSION = '0.1.0';
+$Neovim::RPC::API::Command::VERSION = '0.2.0';
 use strict;
 use warnings;
 
@@ -56,7 +56,7 @@ sub args_to_struct {
         pairmap {
             my $type = $self->api->types->{$a};
             defined $type
-                ? MsgPack::Type::Ext->new( type => $type, data => $b )
+                ? MsgPack::Type::Ext->new( type => $type, data => $b )->data
                 : $b
         }
         map { $_->[0] => $is_hash ? $args{$_->[1]} : shift @args } $self->all_parameters ]
@@ -83,7 +83,7 @@ Neovim::RPC::API::Command
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 AUTHOR
 
